#Module-Specific definitions
%define mod_version %{ap_version}
%define release 2mdk
%define mod_name mod_ssl+distcache
%define mod_so %{mod_name}.so

#New ADVX macros
%define ADVXdir %{_datadir}/ADVX
%{expand:%(cat %{ADVXdir}/ADVX-build)}
%{expand:%%global ap_version %(%{apxs} -q ap_version)}

# Standard Module Definitions
%define name %{ap_name}-%{mod_name}
%define version %{ap_version}_%{mod_version}

#Standard ADVX requires
Prereq:		%{ap_name} = %{ap_version}
Prereq:		%{ap_name}-conf
BuildPreReq:	ADVX-build >= 9.2
BuildRequires:	%{ap_name}-devel >= 2.0.48-4mdk
BuildRequires:	%{ap_name}-source >= 2.0.48-4mdk
Provides: 	ADVXpackage
Provides:	AP20package

Summary:	Strong cryptography using the SSL, TLS and distcache protocols
Name:		%{name}
Version:	%{mod_version}
Release:	%{release}
Group:		System/Servers
Source5: 	gentestcrt.sh.bz2
Source40: 	40_mod_ssl.conf.bz2
Source41: 	41_mod_ssl.default-vhost.conf.bz2
License:	GPL
URL:		http://www.distcache.org
Prereq:		rpm-helper
#Requires:	distcache-server >= 1.4.3
#Requires:	distcache-client >= 1.4.3
BuildRequires:	distcache-devel >= 1.4.3
Provides:	%{ap_name}-mod_ssl
#Conflicts:	%{ap_name}-mod_ssl
BuildRoot:	%{_tmppath}/%{name}-buildroot

%description
This module provides SSL v2/v3 and TLS v1 support for the Apache
HTTP Server. It was contributed by Ralf S. Engeschall based on
his mod_ssl project and originally derived from work by Ben
Laurie.

This module relies on OpenSSL to provide the cryptography engine.

This module is a drop in replacement for the standard mod_ssl with
additional distcache functionality.

Read more about distcache here:

http://www.distcache.org

%prep

%build

# Use the source Luke (apache2 is allready patched)
[ "./%{mod_name}-%{mod_version}" != "/" ] && rm -rf ./%{mod_name}-%{mod_version}
mkdir -p %{mod_name}-%{mod_version}
cp -p %{ap_abs_srcdir}/modules/ssl/* %{mod_name}-%{mod_version}/
cp -p %{ap_abs_srcdir}/modules/loggers/* %{mod_name}-%{mod_version}/

# fix one obsticle
perl -pi -e "s|../../modules/loggers/||g" %{mod_name}-%{mod_version}/ssl_engine_vars.c

pushd %{mod_name}-%{mod_version}
%{apxs} -I%{_includedir}/openssl -I%{_includedir}/distcache -I%{_includedir}/libnal \
    -lssl -lcrypto -ldistcache -lnal -lpthread -DHAVE_OPENSSL -DHAVE_DISTCACHE \
    -c mod_ssl.c ssl_engine_config.c ssl_engine_dh.c ssl_engine_init.c \
    ssl_engine_io.c ssl_engine_kernel.c ssl_engine_log.c ssl_engine_mutex.c \
    ssl_engine_pphrase.c ssl_engine_rand.c ssl_engine_vars.c ssl_expr.c \
    ssl_expr_eval.c ssl_expr_parse.c ssl_expr_scan.c ssl_scache.c \
    ssl_scache_dbm.c ssl_scache_shmcb.c ssl_scache_shmht.c ssl_scache_dc.c \
    ssl_util.c ssl_util_ssl.c ssl_util_table.c
popd

%install
[ "%{buildroot}" != "/" ] && rm -rf %{buildroot}

pushd %{mod_name}-%{mod_version}

install -d %{buildroot}%{ap_extralibs}
install -m0755 .libs/mod_ssl.so %{buildroot}%{ap_extralibs}/

install -d %{buildroot}%{ap_ssldir}
bzcat %{SOURCE5} > %{buildroot}%{ap_ssldir}/gentestcrt.sh

# install module conf files for the "conf.d" dir loading structure
install -d %{buildroot}/%{ap_confd}
bzcat %{SOURCE40} > %{buildroot}/%{ap_confd}/40_mod_ssl.conf
bzcat %{SOURCE41} > %{buildroot}/%{ap_confd}/41_mod_ssl.default-vhost.conf

install -d %{buildroot}%{ap_sslconf}
cat > %{buildroot}%{ap_sslconf}/README.test-certificates <<EOF
Use the %{ap_ssldir}/gentestcrt.sh script to generate your own,
self-signed certificates to replace the localhost server name.
EOF

install -d %{buildroot}%{ap_proxycachedir}

# fix a msec safe cache for the ssl stuff
install -d %{buildroot}%{ap_proxycachedir}/mod_ssl
touch %{buildroot}%{ap_proxycachedir}/mod_ssl/scache.dir
touch %{buildroot}%{ap_proxycachedir}/mod_ssl/scache.pag
touch %{buildroot}%{ap_proxycachedir}/mod_ssl/scache.sem

popd

%clean
[ "./%{mod_name}-%{mod_version}" != "/" ] && rm -rf ./%{mod_name}-%{mod_version}
[ "%{buildroot}" != "/" ] && rm -rf %{buildroot}


%post
if [ $1 = "1" ]; then 
  #Create a self-signed server key and certificate 
  #The script checks first if they exists, if yes, it exits, 
  #otherwise, it creates them.
  if [ -d %{ap_sslconf} ];then
    pushd %{ap_sslconf} > /dev/null
    yes ""|%{ap_ssldir}/gentestcrt.sh >/dev/null 
    popd > /dev/null
  fi
  %{ADVXdir}/mod_ssl-migrate-20
fi
%create_ghostfile %{ap_proxycachedir}/mod_ssl/scache.dir  apache root 0600
%create_ghostfile %{ap_proxycachedir}/mod_ssl/scache.pag  apache root 0600
%create_ghostfile %{ap_proxycachedir}/mod_ssl/scache.sem  apache root 0600
%ADVXpost

%postun
%ADVXpost

%files
%defattr(-,root,root)
%{ap_extralibs}/mod_ssl.so
%doc %{mod_name}-%{mod_version}/README.distcache
%attr(0640,root,root) %config(noreplace) %{ap_confd}/*_mod_ssl.conf
%attr(0640,root,root) %config(noreplace) %{ap_confd}/*_mod_ssl.default-vhost.conf
%config(noreplace) %{ap_sslconf}/README*
%dir %{ap_ssldir}
%attr(0755,root,root) %{ap_ssldir}/gentestcrt.sh
%attr(0700,root,root) %dir %{ap_proxycachedir}/mod_ssl
%attr(0600,apache,root) %ghost %{ap_proxycachedir}/mod_ssl/scache.dir
%attr(0600,apache,root) %ghost %{ap_proxycachedir}/mod_ssl/scache.pag
%attr(0600,apache,root) %ghost %{ap_proxycachedir}/mod_ssl/scache.sem

%changelog
* Mon Dec 15 2003 Oden Eriksson <oden.eriksson@kvikkjokk.net> 2.0.48-2mdk
- argh!!! it cannot conflict with itself!

* Mon Dec 15 2003 Oden Eriksson <oden.eriksson@kvikkjokk.net> 2.0.48-1mdk
- initial cooker contrib
